@@ -12,7 +12,7 @@
 #include <Akonadi/ItemModifyJob>
 
 #include <QStringList>
-#include <KCalCore/Todo>
+#include <KCalendarCore/Todo>
 
 using Akonadi::Serializer;
 
@@ -24,7 +24,7 @@ Zanshin021Migrator::Zanshin021Migrator()
 bool Zanshin021Migrator::isProject(const Akonadi::Item& item)
 {
     // same as Serializer::isProject, but we don't need the serializer here...
-    return item.hasPayload<KCalCore::Todo::Ptr>() && !item.payload<KCalCore::Todo::Ptr>()->customProperty(Serializer::customPropertyAppName(), Serializer::customPropertyIsProject()).isEmpty();
+    return item.hasPayload<KCalendarCore::Todo::Ptr>() && !item.payload<KCalendarCore::Todo::Ptr>()->customProperty(Serializer::customPropertyAppName(), Serializer::customPropertyIsProject()).isEmpty();
 }
 
 
@@ -41,8 +41,8 @@ Zanshin021Migrator::SeenItemHash Zanshin021Migrator::fetchAllItems()
         job->kjob()->exec();
         auto items = job->items();
         foreach (const Akonadi::Item &item, items) {
-            if (item.hasPayload<KCalCore::Todo::Ptr>()) {
-                auto todo = item.payload<KCalCore::Todo::Ptr>();
+            if (item.hasPayload<KCalendarCore::Todo::Ptr>()) {
+                auto todo = item.payload<KCalendarCore::Todo::Ptr>();
                 hash.insert(todo->uid(), SeenItem(item));
             }
         }
@@ -55,7 +55,7 @@ void Zanshin021Migrator::markAsProject(SeenItem& seenItem, Akonadi::TransactionS
 {
     Akonadi::Item &item = seenItem.item();
     if (!isProject(item)) {
-        auto todo = item.payload<KCalCore::Todo::Ptr>();
+        auto todo = item.payload<KCalendarCore::Todo::Ptr>();
         todo->setCustomProperty(Serializer::customPropertyAppName(), Serializer::customPropertyIsProject(), QStringLiteral("1"));
         item.setPayload(todo);
         seenItem.setDirty();
@@ -69,7 +69,7 @@ void Zanshin021Migrator::migrateProjectComments(Zanshin021Migrator::SeenItemHash
     for (SeenItemHash::iterator it = items.begin(); it != items.end(); ++it) {
         SeenItem &seenItem = it.value();
         Akonadi::Item &item = seenItem.item();
-        auto todo = item.payload<KCalCore::Todo::Ptr>();
+        auto todo = item.payload<KCalendarCore::Todo::Ptr>();
         if (todo->comments().contains(QStringLiteral("X-Zanshin-Project")))
             markAsProject(seenItem, sequence);
     }
@@ -79,7 +79,7 @@ void Zanshin021Migrator::migrateProjectWithChildren(Zanshin021Migrator::SeenItem
 {
     for (SeenItemHash::iterator it = items.begin(); it != items.end(); ++it) {
         const SeenItem &seenItem = it.value();
-        const auto todo = seenItem.item().payload<KCalCore::Todo::Ptr>();
+        const auto todo = seenItem.item().payload<KCalendarCore::Todo::Ptr>();
         const QString parentUid = todo->relatedTo();
         if (!parentUid.isEmpty()) {
             auto parentIt = items.find(parentUid);
